==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressPodSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressPodSpecBuilder extends ACMEChallengeSolverHTTP01IngressPodSpecFluentImpl<ACMEChallengeSolverHTTP01IngressPodSpecBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodSpec,ACMEChallengeSolverHTTP01IngressPodSpecBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressPodSpec(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodSpec(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodSpec instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAffinity(instance.getAffinity());
      fluent.withNodeSelector(instance.getNodeSelector());
      fluent.withPriorityClassName(instance.getPriorityClassName());
      fluent.withServiceAccountName(instance.getServiceAccountName());
      fluent.withTolerations(instance.getTolerations());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpec instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAffinity(instance.getAffinity());
      this.withNodeSelector(instance.getNodeSelector());
      this.withPriorityClassName(instance.getPriorityClassName());
      this.withServiceAccountName(instance.getServiceAccountName());
      this.withTolerations(instance.getTolerations());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressPodSpec build() {
    ACMEChallengeSolverHTTP01IngressPodSpec buildable = new ACMEChallengeSolverHTTP01IngressPodSpec(fluent.getAffinity(),fluent.getNodeSelector(),fluent.getPriorityClassName(),fluent.getServiceAccountName(),fluent.getTolerations());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressPodSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressPodSpecBuilder extends ACMEChallengeSolverHTTP01IngressPodSpecFluent<ACMEChallengeSolverHTTP01IngressPodSpecBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodSpec,ACMEChallengeSolverHTTP01IngressPodSpecBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressPodSpec(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodSpec(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodSpec instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodSpec());

    if (instance != null) {
      fluent.withAffinity(instance.getAffinity());
      fluent.withNodeSelector(instance.getNodeSelector());
      fluent.withPriorityClassName(instance.getPriorityClassName());
      fluent.withServiceAccountName(instance.getServiceAccountName());
      fluent.withTolerations(instance.getTolerations());
      fluent.withAffinity(instance.getAffinity());
      fluent.withNodeSelector(instance.getNodeSelector());
      fluent.withPriorityClassName(instance.getPriorityClassName());
      fluent.withServiceAccountName(instance.getServiceAccountName());
      fluent.withTolerations(instance.getTolerations());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpec instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressPodSpecBuilder(ACMEChallengeSolverHTTP01IngressPodSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodSpec());

    if (instance != null) {
      this.withAffinity(instance.getAffinity());
      this.withNodeSelector(instance.getNodeSelector());
      this.withPriorityClassName(instance.getPriorityClassName());
      this.withServiceAccountName(instance.getServiceAccountName());
      this.withTolerations(instance.getTolerations());
      this.withAffinity(instance.getAffinity());
      this.withNodeSelector(instance.getNodeSelector());
      this.withPriorityClassName(instance.getPriorityClassName());
      this.withServiceAccountName(instance.getServiceAccountName());
      this.withTolerations(instance.getTolerations());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressPodSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressPodSpec build() {
    ACMEChallengeSolverHTTP01IngressPodSpec buildable = new ACMEChallengeSolverHTTP01IngressPodSpec(fluent.getAffinity(),fluent.getNodeSelector(),fluent.getPriorityClassName(),fluent.getServiceAccountName(),fluent.getTolerations());
    return buildable;
  }
  
}
